@@ -15,7 +15,7 @@ from .args import reconstruct_args, PikaurArgs, parse_args
 from .aur import AURPackageInfo
 from .pacman import (
     PackageDB,
-    get_pacman_command, refresh_pkg_db, install_built_deps, strip_repo_name,
+    get_pacman_command, refresh_pkg_db_if_needed, install_built_deps, strip_repo_name,
 )
 from .install_info_fetcher import InstallInfoFetcher
 from .exceptions import (
@@ -133,7 +133,7 @@ class InstallPackagesCLI():
                     )
                 if self.args.refresh:
                     threads.append(
-                        pool.apply_async(refresh_pkg_db, ())
+                        pool.apply_async(refresh_pkg_db_if_needed, ())
                     )
                 pool.close()
                 for thread in threads:
@@ -204,7 +204,7 @@ class InstallPackagesCLI():
     def aur_pkg_not_found_prompt(self, pkg_name: str) -> None:  # pragma: no cover
         prompt = '{} {}\n{}\n{}\n{}\n> '.format(
             color_line('::', 11),
-            _("Try recovering?"),
+            _("Try recovering {pkg_name}?").format(pkg_name=bold_line(pkg_name)),
             _("[e] edit PKGBUILD"),
             _("[s] skip this package"),
             _("[A] abort")
