@@ -22,14 +22,14 @@ from .args import (
 )
 from .help_cli import cli_print_help
 from .core import (
-    InstallInfo,
+    DEFAULT_INPUT_ENCODING, InstallInfo,
     spawn, interactive_spawn, remove_dir, check_runtime_deps,
     running_as_root, sudo, isolate_root_cmd, run_with_sudo_loop,
 )
 from .pprint import (
     color_line, bold_line,
     print_stderr, print_stdout,
-    print_error, print_warning,
+    print_error, print_warning, print_debug,
 )
 from .print_department import (
     pretty_format_upgradeable, print_version,
@@ -70,9 +70,9 @@ def init_output_encoding() -> None:
         try:
             setattr(
                 sys, attr,
-                codecs.open(
+                codecs.open(  # pylint: disable=consider-using-with
                     real_stream.fileno(),
-                    mode='w', buffering=0, encoding='utf-8'
+                    mode='w', buffering=0, encoding=DEFAULT_INPUT_ENCODING
                 )
             )
         except io.UnsupportedOperation:
@@ -249,6 +249,7 @@ def cli_entry_point() -> None:  # pylint: disable=too-many-statements
         require_sudo = True
 
     if pikaur_operation:
+        print_debug(f"Pikaur operation found for {sys.argv=}: {pikaur_operation.__name__}")
         if require_sudo and args.dynamic_users and not running_as_root():
             # Restart pikaur with sudo to use systemd dynamic users
             restart_args = sys.argv[:]
@@ -270,7 +271,11 @@ def cli_entry_point() -> None:  # pylint: disable=too-many-statements
                 run_with_sudo_loop(pikaur_operation)
     else:
         # Just bypass all the args to pacman
-        pacman_args = [PikaurConfig().misc.PacmanPath.get_str(), ] + (args.raw or [])
+        print_debug(f"Pikaur operation not found for {sys.argv=}")
+        print_debug(args)
+        pacman_args = [
+            PikaurConfig().misc.PacmanPath.get_str(),
+        ] + args.raw_without_pikaur_specific
         if require_sudo:
             pacman_args = sudo(pacman_args)
         sys.exit(
