@@ -126,19 +126,27 @@ DB_LOCK_LOCAL = Lock()
 class DbLockRepo():
 
     def __enter__(self) -> None:
-        DB_LOCK_REPO.acquire()
+        DB_LOCK_REPO.acquire()  # pylint: disable=consider-using-with
 
     def __exit__(self, *_exc_details) -> None:
-        DB_LOCK_REPO.release()
+        if DB_LOCK_REPO.locked():
+            DB_LOCK_REPO.release()
+
+    def __del__(self):
+        self.__exit__()
 
 
 class DbLockLocal():
 
     def __enter__(self) -> None:
-        DB_LOCK_LOCAL.acquire()
+        DB_LOCK_LOCAL.acquire()  # pylint: disable=consider-using-with
 
     def __exit__(self, *_exc_details) -> None:
-        DB_LOCK_LOCAL.release()
+        if DB_LOCK_LOCAL.locked():
+            DB_LOCK_LOCAL.release()
+
+    def __del__(self):
+        self.__exit__()
 
 
 def get_db_lock(package_source: PackageSource):
@@ -556,7 +564,7 @@ def find_packages_not_from_repo() -> List[str]:
     return not_found_packages
 
 
-def refresh_pkg_db() -> None:
+def refresh_pkg_db_if_needed() -> None:
     args = parse_args()
     if args.refresh:
         pacman_args = (sudo(
