@@ -22,7 +22,7 @@ from .pprint import (
 )
 from .pacman_i18n import _p
 from .args import parse_args
-from .core import get_sudo_refresh_command
+from .core import get_sudo_refresh_command, DEFAULT_INPUT_ENCODING
 
 
 # SMALL_TIMEOUT = 0.1
@@ -32,6 +32,10 @@ SMALL_TIMEOUT = 0.01
 TcAttrsType = List[Union[int, List[Union[bytes, int]]]]
 
 
+def _debug(message):
+    print_debug(f"pikspect: {message}", lock=False)
+
+
 class TTYRestore():
 
     old_tcattrs = None
@@ -80,19 +84,50 @@ def set_terminal_geometry(file_descriptor: int, rows: int, columns: int) -> None
     )
 
 
-class NestedTerminal():
+class TTYInputWrapper():
 
-    def __enter__(self) -> os.terminal_size:
-        real_term_geometry = shutil.get_terminal_size((80, 80))
-        if sys.stdin.isatty():
-            tty.setcbreak(sys.stdin.fileno())
-            if sys.stderr.isatty():
-                tty.setcbreak(sys.stderr.fileno())
-            if sys.stdout.isatty():
-                tty.setcbreak(sys.stdout.fileno())
-        return real_term_geometry
+    tty_opened = False
+
+    def __init__(self):
+        self.is_pipe = not sys.stdin.isatty()
+
+    def __enter__(self):
+        if self.is_pipe:
+            self.old_stdin = sys.stdin
+            try:
+                _debug('Attaching to TTY manually...')
+                sys.stdin = open('/dev/tty', encoding=DEFAULT_INPUT_ENCODING)  # pylint:disable=consider-using-with
+                self.tty_opened = True
+            except Exception as exc:
+                _debug(exc)
 
     def __exit__(self, *_exc_details) -> None:
+        if self.is_pipe and self.tty_opened:
+            _debug('Restoring stdin...')
+            sys.stdin.close()
+            sys.stdin = self.old_stdin
+
+
+class NestedTerminal():
+
+    def __init__(self):
+        self.tty_wrapper = TTYInputWrapper()
+
+    def __enter__(self) -> os.terminal_size:
+        _debug("Opening virtual terminal...")
+        self.tty_wrapper.__enter__()
+        real_term_geometry = shutil.get_terminal_size((80, 80))
+        for stream in (
+                sys.stdin,
+                sys.stderr,
+                sys.stdout,
+        ):
+            if stream.isatty():
+                tty.setcbreak(stream.fileno())
+        return real_term_geometry
+
+    def __exit__(self, *exc_details) -> None:
+        self.tty_wrapper.__exit__(*exc_details)
         TTYRestore.restore()
 
 
@@ -168,19 +203,24 @@ class PikspectPopen(subprocess.Popen):  # pylint: disable=too-many-instance-attr
             self.default_questions[answer] = self.default_questions.get(answer, []) + questions
             for question in questions:
                 if len(question) > self.max_question_length:
-                    self.max_question_length = len(question.encode('utf-8'))
+                    self.max_question_length = len(question.encode(DEFAULT_INPUT_ENCODING))
         self.check_questions()
 
     def communicator_thread(self) -> int:
         return self._wait(None)
 
     def run(self) -> None:
+        if not isinstance(self.args, list):
+            raise TypeError('self.args should be list')
         PikspectSignalHandler.set(lambda *_whatever: self.send_signal(signal.SIGINT))
         try:
             with NestedTerminal() as real_term_geometry:
+
                 if 'sudo' in self.args:
                     subprocess.run(get_sudo_refresh_command(), check=True)
-                with open(self.pty_user_master, 'w') as self.pty_in:
+                with open(
+                        self.pty_user_master, 'w', encoding=DEFAULT_INPUT_ENCODING
+                ) as self.pty_in:
                     with open(self.pty_cmd_master, 'rb', buffering=0) as self.pty_out:
                         set_terminal_geometry(
                             self.pty_out.fileno(),
@@ -207,7 +247,7 @@ class PikspectPopen(subprocess.Popen):  # pylint: disable=too-many-instance-attr
     def check_questions(self) -> None:
         # pylint: disable=too-many-branches
         try:
-            historic_output = b''.join(self.historic_output).decode('utf-8')
+            historic_output = b''.join(self.historic_output).decode(DEFAULT_INPUT_ENCODING)
         except UnicodeDecodeError:
             return
 
@@ -217,7 +257,7 @@ class PikspectPopen(subprocess.Popen):  # pylint: disable=too-many-instance-attr
             for question in questions:
                 if not _match(question, historic_output):
                     continue
-                self.write_something((answer + '\n').encode('utf-8'))
+                self.write_something((answer + '\n').encode(DEFAULT_INPUT_ENCODING))
                 with PrintLock():
                     self.pty_in.write(answer)
                     sleep(SMALL_TIMEOUT)
@@ -291,13 +331,15 @@ class PikspectPopen(subprocess.Popen):  # pylint: disable=too-many-instance-attr
                     if ord(char) == 23:  # Ctrl+W
                         sys.stdout.write(
                             '\r' + ' ' * get_term_width() + '\r' +
-                            b''.join(self.historic_output).decode('utf-8').splitlines()[-1]
+                            b''.join(
+                                self.historic_output
+                            ).decode(DEFAULT_INPUT_ENCODING).splitlines()[-1]
                         )
                     self.pty_in.write(char)
                     self.pty_in.flush()
             except ValueError as exc:
                 print(exc)
-            self.write_something(char.encode('utf-8'))
+            self.write_something(char.encode(DEFAULT_INPUT_ENCODING))
 
 
 # pylint: disable=too-many-locals,too-many-arguments
@@ -320,7 +362,10 @@ def pikspect(
         return bold_line(" {} {} ".format(_p(message), question))
 
     class Questions:
-        PROCEED = format_pacman_question('Proceed with installation?')
+        PROCEED = [
+            format_pacman_question('Proceed with installation?'),
+            format_pacman_question('Proceed with download?'),
+        ]
         REMOVE = format_pacman_question('Do you want to remove these packages?')
         CONFLICT = format_pacman_question(
             '%s and %s are in conflict. Remove %s?', YesNo.QUESTION_YN_NO
@@ -345,8 +390,7 @@ def pikspect(
     default_questions: Dict[str, List[str]] = {}
     if auto_proceed:
         default_questions = {
-            YesNo.ANSWER_Y: [
-                Questions.PROCEED,
+            YesNo.ANSWER_Y: Questions.PROCEED + [
                 Questions.REMOVE,
             ],
             YesNo.ANSWER_N: [],
@@ -368,7 +412,7 @@ def pikspect(
         proc.add_answers(extra_questions)
 
     if parse_args().print_commands:
-        print_stderr(color_line('=> ', 14) + ' '.join(cmd))
+        print_stderr(color_line('pikspect => ', 14) + ' '.join(cmd))
     proc.run()
     return proc
 
